==> oldalbum-2.0.0.tar.gz: oldalbum/oldalbum.web.frontend/src/main/frontend/src/components/PictureNavbar.js <==
import React from 'react';
import { useSelector } from 'react-redux';
import { NavLink } from 'react-router-dom';
import Locale from './Locale';
import EditModeButton from './EditModeButton';
import CopyLinkButton from './CopyLinkButton';
import ReloadShiroConfigButton from './ReloadShiroConfigButton';
import TogglePasswordProtection from './TogglePasswordProtection';
import DownloadButton from './DownloadButton';
import LoginLogoutButton from './LoginLogoutButton';

export default function PictureNavbar(props) {
    const { className, item, parent, title } = props;
    const text = useSelector(state => state.displayTexts);
    const anchor = 'entry' + item.id.toString();

    return (
        <div className={className}>
            <nav className="navbar navbar-light bg-light">
                <NavLink className="nav-link" to={parent + '#' + anchor}>
                    <div className="container">
                        <div className="column">
                            <span className="row oi oi-chevron-top" title="chevron top" aria-hidden="true"></span>
                            <div className="row">{text.up}</div>
                        </div>
                    </div>
                </NavLink>
                <h1 className="navbar-text">{title}</h1>
                <div className="d-flex flex-row">
                    <DownloadButton className="nav-link float-right" item={item} />
                    <Locale className="form-inline" />
                    <div className="dropdown">
                        <button className="dropdown-toggle" type="button" id="dropdownMenuButton" data-bs-toggle="dropdown" aria-expanded="false">
                            <span className="navbar-toggler-icon"></span>
                        </button>
                        <ul className="dropdown-menu dropdown-menu-end">
                            <li><CopyLinkButton className="dropdown-item" item={item} /></li>
                            <li><ReloadShiroConfigButton className="dropdown-item"/></li>
                            <li><TogglePasswordProtection className="dropdown-item" item={item}/></li>
                            <li><EditModeButton className="dropdown-item" /></li>
                            <li><LoginLogoutButton className="dropdown-item" item={item}/></li>
                        </ul>
                    </div>
                </div>
            </nav>
        </div>
    );
}

==> oldalbum-2.1.0.tar.gz: oldalbum/oldalbum.web.frontend/src/main/frontend/src/components/PictureNavbar.js <==
import React from 'react';
import { useSelector } from 'react-redux';
import { NavLink } from 'react-router-dom';
import Locale from './Locale';
import EditModeButton from './EditModeButton';
import CopyLinkButton from './CopyLinkButton';
import ReloadShiroConfigButton from './ReloadShiroConfigButton';
import TogglePasswordProtection from './TogglePasswordProtection';
import DownloadButton from './DownloadButton';
import LoginLogoutButton from './LoginLogoutButton';

export default function PictureNavbar(props) {
    const { className, item, parent, title } = props;
    const text = useSelector(state => state.displayTexts);
    const anchor = item.path.split('/').pop();

    return (
        <div className={className}>
            <nav className="navbar navbar-light bg-light">
                <NavLink className="nav-link" to={parent + '#' + anchor}>
                    <div className="container">
                        <div className="column">
                            <span className="row oi oi-chevron-top" title="chevron top" aria-hidden="true"></span>
                            <div className="row">{text.up}</div>
                        </div>
                    </div>
                </NavLink>
                <h1 className="navbar-text">{title}</h1>
                <div className="d-flex flex-row">
                    <DownloadButton className="nav-link float-right" item={item} />
                    <Locale className="form-inline" />
                    <div className="dropdown">
                        <button className="dropdown-toggle" type="button" id="dropdownMenuButton" data-bs-toggle="dropdown" aria-expanded="false">
                            <span className="navbar-toggler-icon"></span>
                        </button>
                        <ul className="dropdown-menu dropdown-menu-end">
                            <li><CopyLinkButton className="dropdown-item" item={item} /></li>
                            <li><ReloadShiroConfigButton className="dropdown-item"/></li>
                            <li><TogglePasswordProtection className="dropdown-item" item={item}/></li>
                            <li><EditModeButton className="dropdown-item" /></li>
                            <li><LoginLogoutButton className="dropdown-item" item={item}/></li>
                        </ul>
                    </div>
                </div>
            </nav>
        </div>
    );
}
